@@ -202,11 +202,18 @@ i18n_noops[] = {
     N_("Block Outlook during encrypt / sign"),
     /* TRANSLATORS: Config dialog debug page, can be technical. */
     N_("Block Outlook during decrypt / verify"),
+    /* TRANSLATORS: Config dialog debug page, can be technical. */
+    N_("Do not save encrypted mails before decryption"),
     /* TRANSLATORS: Config dialog debug page, link to report bug page. */
     N_("How to report a problem?"),
     /* TRANSLATORS: Config dialog. */
     N_("&Always show security approval dialog"),
     N_("(slow)"),
+    /* TRANSLATORS: Config dialog. */
+    N_("Help"),
+    /* TRANSLATORS: Only available in german and english please keep
+       english for other langs */
+    N_("handout_outlook_plugin_gnupg_en.pdf"),
     /* TRANSLATORS: Config dialog tooltip. */
     N_("Always show the security approval and certificate selection dialog. "
        "This slows down the encryption / signing process, especially with large keyrings."),
@@ -270,7 +277,7 @@ open_gpgolconfig (LPVOID arg)
   if (err)
     {
       log_error ("%s:%s: Err code: %i asString: %s",
-                 SRCNAME, __func__, err.code(), err.asString());
+                 SRCNAME, __func__, err.code(), err.asStdString().c_str());
     }
   dlg_open = false;
 
